@codecademy/gamut

73.5.073.5.1-alpha.7af239.0
dist/Form/SelectDropdown/elements/containers.js
~dist/Form/SelectDropdown/elements/containers.jsModified
+4−2
Index: package/dist/Form/SelectDropdown/elements/containers.js
===================================================================
--- package/dist/Form/SelectDropdown/elements/containers.js
+++ package/dist/Form/SelectDropdown/elements/containers.js
@@ -1,17 +1,19 @@
 import { createContext, useEffect, useLayoutEffect } from 'react';
 import ReactSelect, { components as SelectDropdownElements } from 'react-select';
 import CreatableSelect from 'react-select/creatable';
+import { DEFAULT_SELECT_DROPDOWN_TRANSLATIONS } from '../core/translations';
 import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
 /**
  * React context for sharing state between SelectDropdown components.
  * Provides access to focus state and refs for keyboard navigation.
  */
 export const SelectDropdownContext = /*#__PURE__*/createContext({
   currentFocusedValue: undefined,
   setCurrentFocusedValue: undefined,
   selectInputRef: undefined,
-  removeAllButtonRef: undefined
+  removeAllButtonRef: undefined,
+  translations: DEFAULT_SELECT_DROPDOWN_TRANSLATIONS
 });
 
 /**
@@ -1,17 +1,19 @@
 /**
  * React context for sharing state between SelectDropdown components.
- * Provides access to focus state and refs for keyboard navigation.
+ * Provides access to focus state, refs for keyboard navigation, and translations.
  */
 export const SelectDropdownContext = /*#__PURE__*/createContext({
  * Wraps react-select's `NoOptionsMessage` to report its text via